#!/bin/bash

{% include('init/linux.sh.twig') %}

{% include('init/security.sh.twig') %}

{% if nginx %}
    {% include('init/nginx.sh.twig') %}
{% endif %}

{% if mysql %}
    {% include('init/mysql.sh.twig') %}
{% endif %}

{% if redis %}
    {% include('init/redis.sh.twig') %}
{% endif %}

{% if php %}
    {% include('init/php.sh.twig') %}
{% endif %}

{% if nodejs %}
    {% include('init/nodejs.sh.twig') %}
{% endif %}

{% if jobber %}
    {% include('init/jobber.sh.twig') %}
{% endif %}

{% if supervisor %}
    {% include('init/supervisor.sh.twig') %}
{% endif %}

# DONE
echo "BAMMMMM ! It's done !"
echo "=== Your MySQL user / password : lenmay / {{ mysql_root_password }}"
