#!/bin/bash

# Install Jobber
wget https://github.com/dshearer/jobber/releases/download/v1.4.4/jobber_1.4.4-1_amd64.deb && sudo dpkg -i jobber_1.4.4-1_amd64.deb && rm -f jobber_1.4.4-1_amd64.deb
sudo systemctl enable jobber.service
sudo systemctl restart jobber.service
